==> my-grid-system-1.1.0.tgz: package/gulpfile.js <==
//
// Gulp setup
//

var gulp            = require('gulp'),
    concat          = require('gulp-concat'),
    notify          = require('gulp-notify'),
    plumber         = require('gulp-plumber'),
    sourcemaps      = require('gulp-sourcemaps');

//
// PostCSS plugins
//

var postcss         = require('gulp-postcss'),
    advancedvars    = require('postcss-advanced-variables'),
    autoprefixer    = require('autoprefixer'),
    csswring        = require('csswring'),
    conditionals    = require('postcss-conditionals'),
    cssfor          = require('postcss-for'),
    mathjs          = require('postcss-mathjs'),
    mixins          = require('postcss-mixins'),
    nested          = require('postcss-nested'),
    partialimport   = require('postcss-partial-import');

//
// CSS (the order of 'processors' is important!!!)
//

gulp.task('css', function(){
  return gulp.src('./src/style.css')
    .pipe(plumber(plumberErrorHandler))
    .pipe(concat('grid.css'))
    .pipe(postcss([
      partialimport,
      mixins,
      advancedvars,
      nested,
      cssfor,
      conditionals,
      mathjs,
      autoprefixer({ browsers: ['last 2 versions', '> 5%'] })
    ]))
    .pipe(gulp.dest('./dist'));
});

gulp.task('css-minify', function(){
  return gulp.src('./src/style.css')
    .pipe(plumber(plumberErrorHandler))
    .pipe(sourcemaps.init())
    .pipe(concat('grid.min.css'))
    .pipe(postcss([
      partialimport,
      mixins,
      advancedvars,
      nested,
      cssfor,
      conditionals,
      mathjs,
      autoprefixer({ browsers: ['last 2 versions', '> 5%'] }),
      csswring
    ]))
    .pipe(sourcemaps.write('.'))
    .pipe(gulp.dest('./dist'));
});

//
// Watch
//

gulp.task('watch', function() {

  gulp.watch('./src/**/*.css', ['css', 'css-minify']);

});

//
// Error Handling
//

var plumberErrorHandler = { errorHandler: notify.onError({
  title: 'Gulp',
  message: 'Error: <%= error.message %>'
  })
};

//
// Default Gulp Task
//

gulp.task('default', ['css', 'css-minify', 'watch']);
gulp.task('install', ['css', 'css-minify']);

==> my-grid-system-1.3.0.tgz: package/gulpfile.js <==
//
// Gulp setup
//

var gulp            = require('gulp'),
    concat          = require('gulp-concat'),
    notify          = require('gulp-notify'),
    plumber         = require('gulp-plumber'),
    sourcemaps      = require('gulp-sourcemaps');

//
// PostCSS plugins
//

var postcss         = require('gulp-postcss'),
    advancedvars    = require('postcss-advanced-variables'),
    autoprefixer    = require('autoprefixer'),
    csswring        = require('csswring'),
    conditionals    = require('postcss-conditionals'),
    cssfor          = require('postcss-for'),
    mathjs          = require('postcss-mathjs'),
    mixins          = require('postcss-mixins'),
    nested          = require('postcss-nested'),
    partialimport   = require('postcss-partial-import');

//
// CSS (the order of 'processors' is important!!!)
//

gulp.task('css', function(){
  return gulp.src('./src/style.css')
    .pipe(plumber(plumberErrorHandler))
    .pipe(concat('grid.css'))
    .pipe(postcss([
      partialimport,
      mixins,
      advancedvars,
      nested,
      cssfor,
      conditionals,
      mathjs,
      autoprefixer({ browsers: ['last 2 versions', '> 5%'] })
    ]))
    .pipe(gulp.dest('./dist'));
});

gulp.task('css-minify', function(){
  return gulp.src('./src/style.css')
    .pipe(plumber(plumberErrorHandler))
    .pipe(sourcemaps.init())
    .pipe(concat('grid.min.css'))
    .pipe(postcss([
      partialimport,
      mixins,
      advancedvars,
      nested,
      cssfor,
      conditionals,
      mathjs,
      autoprefixer({ browsers: ['last 2 versions', '> 5%'] }),
      csswring
    ]))
    .pipe(sourcemaps.write('.'))
    .pipe(gulp.dest('./dist'));
});

//
// Watcher
//

gulp.task('watcher', function() {

  gulp.watch('./src/**/*.css', ['css', 'css-minify']);

});

//
// Error Handling
//

var plumberErrorHandler = { errorHandler: notify.onError({
  title: 'Gulp',
  message: 'Error: <%= error.message %>'
  })
};

//
// Default Gulp Task
//

gulp.task('default', ['css', 'css-minify']);
gulp.task('watch', ['css', 'css-minify', 'watcher']);
gulp.task('install', ['css', 'css-minify']);
